This is an automatically generated lising of the new Lua map scripting API, generated for release-20140608 of OpenRA.

OpenRA allows custom maps and missions to be scripted using Lua 5.1.
These scripts run in a sandbox that prevents access to unsafe functions (e.g. OS or file access), and limits the memory and CPU usage of the scripts.

You can access this interface by adding the [LuaScript](Traits#luascript) trait to the world actor in your map rules (note, you must replace the spaces in the snippet below with a single tab for each level of indentation):
```
Rules:
	World:
		LuaScript:
			Scripts: myscript.lua
```

Map scripts can interact with the game engine in three ways:
* Global tables provide functions for interacting with the global world state, or performing general helper tasks.
They exist in the global namespace, and can be called directly using ```<table name>.<function name>```.
* Individual actors expose a collection of properties and commands that query information of modify their state.
  * Some commands, marked as <em>queued activity</em>, are asynchronous.  Activities are queued on the actor, and will run in sequence until the queue is empty or the Stop command is called.  Actors that are not performing an activity are Idle (actor.IsIdle will return true).  The properties and commands available on each actor depends on the traits that the actor specifies in its rule definitions.
* Individual players explose a collection of properties and commands that query information of modify their state.
The properties and commands available on each actor depends on the traits that the actor specifies in its rule definitions.


<h3>Global Tables</h3>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Actor</th></tr>
<tr><td align="right" width="50%"><strong>int BuildTime(string type)</strong></td><td>Returns the build time (in ticks) of the requested unit type</td></tr>
<tr><td align="right" width="50%"><strong>Actor Create(string type, bool addToWorld, LuaTable initTable)</strong></td><td>Create a new actor. initTable specifies a list of key-value pairs that definite initial parameters for the actor's traits.</td></tr>
<tr><td align="right" width="50%"><strong>int CruiseAltitude(string type)</strong></td><td>Returns the cruise altitude of the requested unit type (zero if it ground-based).</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Camera</th></tr>
<tr><td align="right" width="50%"><strong>WPos Position { get; set; }</strong></td><td>The center of the visible viewport.</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">CPos</th></tr>
<tr><td align="right" width="50%"><strong>CPos New(int x, int y)</strong></td><td>Create a new CPos with the specified coordinates.</td></tr>
<tr><td align="right" width="50%"><strong>CPos Zero { get; }</strong></td><td>The cell coordinate origin.</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">CVec</th></tr>
<tr><td align="right" width="50%"><strong>CVec New(int x, int y)</strong></td><td>Create a new CVec with the specified coordinates.</td></tr>
<tr><td align="right" width="50%"><strong>CVec Zero { get; }</strong></td><td>The cell zero-vector.</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Map</th></tr>
<tr><td align="right" width="50%"><strong>LuaTable ActorsInCircle(WPos location, WRange radius, LuaFunction filter)</strong></td><td>Returns a table of all actors within the requested region, filtered using the specified function.</td></tr>
<tr><td align="right" width="50%"><strong>string Difficulty { get; }</strong></td><td>Returns the difficulty selected by the player before starting the mission.</td></tr>
<tr><td align="right" width="50%"><strong>bool IsNamedActor(Actor actor)</strong></td><td>Returns true if actor was originally specified in the map file.</td></tr>
<tr><td align="right" width="50%"><strong>bool IsSinglePlayer { get; }</strong></td><td>Returns true if there is only one human player.</td></tr>
<tr><td align="right" width="50%"><strong>Actor NamedActor(string actorName)</strong></td><td>Returns the actor that was specified with a given name in the map file (or nil, if the actor is dead or not found</td></tr>
<tr><td align="right" width="50%"><strong>LuaTable NamedActors { get; }</strong></td><td>Returns a table of all the actors that were specified in the map file.</td></tr>
<tr><td align="right" width="50%"><strong>CPos RandomCell()</strong></td><td>Returns a random cell inside the visible region of the map.</td></tr>
<tr><td align="right" width="50%"><strong>CPos RandomEdgeCell()</strong></td><td>Returns a random cell on the visible border of the map.</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Player</th></tr>
<tr><td align="right" width="50%"><strong>Player GetPlayer(string name)</strong></td><td>Returns the player with the specified internal name, or nil if a match is not found.</td></tr>
<tr><td align="right" width="50%"><strong>LuaTable GetPlayers(LuaFunction filter)</strong></td><td>Returns a table of players filtered by the specified function.</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Trigger</th></tr>
<tr><td align="right" width="50%"><strong>void AfterDelay(int delay, LuaFunction func)</strong></td><td>Call a function after a specified delay. The callback function will be called as func().</td></tr>
<tr><td align="right" width="50%"><strong>void OnAllKilled(LuaTable actors, LuaFunction func)</strong></td><td>Call a function when all of the actors in a group are killed. The callback function will be called as func().</td></tr>
<tr><td align="right" width="50%"><strong>void OnDamaged(Actor a, LuaFunction func)</strong></td><td>Call a function when the actor is damaged. The callback function will be called as func(Actor self, Actor attacker).</td></tr>
<tr><td align="right" width="50%"><strong>void OnIdle(Actor a, LuaFunction func)</strong></td><td>Call a function each tick that the actor is idle. The callback function will be called as func(Actor self).</td></tr>
<tr><td align="right" width="50%"><strong>void OnKilled(Actor a, LuaFunction func)</strong></td><td>Call a function when the actor is killed. The callback function will be called as func(Actor self, Actor killer).</td></tr>
<tr><td align="right" width="50%"><strong>void OnProduction(Actor a, LuaFunction func)</strong></td><td>Call a function when this actor produces another actor. The callback function will be called as func(Actor producer, Actor produced).</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Utils</th></tr>
<tr><td align="right" width="50%"><strong>bool All(LuaTable table, LuaFunction func)</strong></td><td>Returns true if func returns true for all values in table.</td></tr>
<tr><td align="right" width="50%"><strong>bool Any(LuaTable table, LuaFunction func)</strong></td><td>Returns true if func returns true for any value in table.</td></tr>
<tr><td align="right" width="50%"><strong>WPos CenterOfCell(CPos cell)</strong></td><td>Returns the center of a cell in world coordinates.</td></tr>
<tr><td align="right" width="50%"><strong>void Do(LuaTable table, LuaFunction func)</strong></td><td>Calls a function on every value in table.</td></tr>
<tr><td align="right" width="50%"><strong>LuaTable ExpandFootprint(LuaTable cells, bool allowDiagonal)</strong></td><td>Expands the given footprint one step along the coordinate axes, and (if requested) diagonals</td></tr>
<tr><td align="right" width="50%"><strong>LuaValue Random(LuaTable table)</strong></td><td>Returns a random value from table.</td></tr>
<tr><td align="right" width="50%"><strong>int RandomInteger(int low, int high)</strong></td><td>Returns a random integer x in the range low &lt;= x &lt; high.</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">WPos</th></tr>
<tr><td align="right" width="50%"><strong>WPos New(int x, int y, int z)</strong></td><td>Create a new WPos with the specified coordinates.</td></tr>
<tr><td align="right" width="50%"><strong>WPos Zero { get; }</strong></td><td>The world coordinate origin.</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">WVec</th></tr>
<tr><td align="right" width="50%"><strong>WVec New(int x, int y, int z)</strong></td><td>Create a new WVec with the specified coordinates.</td></tr>
<tr><td align="right" width="50%"><strong>WVec Zero { get; }</strong></td><td>The world zero-vector.</td></tr>
</table>
<h3>Actor Properties / Commands</h3>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Combat</th></tr>
<tr><td width="50%" align="right"><strong>void AttackMove(CPos cell, int closeEnough = 0)</strong>
<br /><em>Queued Activity</em>
</td><td>
Move to a cell, but stop and attack anything within range on the way. closeEnough defines an optional range (in cells) that will be considered close enough to complete the activity.
<br />
<b>Requires Traits:</b> IMove, AttackBase
</td></tr>
<tr><td width="50%" align="right"><strong>void Hunt()</strong>
<br /><em>Queued Activity</em>
</td><td>
Seek out and attack nearby targets.
<br />
<b>Requires Traits:</b> IMove, AttackBase
</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">General</th></tr>
<tr><td width="50%" align="right"><strong>void CallFunc(LuaFunction func)</strong>
<br /><em>Queued Activity</em>
</td><td>
Run an arbitrary lua function.
</td></tr>
<tr><td width="50%" align="right"><strong>WPos CenterPosition { get; }</strong>
</td><td>
The actor position in world coordinates.
</td></tr>
<tr><td width="50%" align="right"><strong>void Destroy()</strong>
<br /><em>Queued Activity</em>
</td><td>
Remove the actor from the game, without triggering any death notification.
</td></tr>
<tr><td width="50%" align="right"><strong>int Facing { get; }</strong>
</td><td>
The direction that the actor is facing.
</td></tr>
<tr><td width="50%" align="right"><strong>bool HasProperty(string name)</strong>
</td><td>
Test whether an actor has a specific property.
</td></tr>
<tr><td width="50%" align="right"><strong>int Health { get; set; }</strong>
</td><td>
Current health of the actor.
<br />
<b>Requires Trait:</b> Health
</td></tr>
<tr><td width="50%" align="right"><strong>bool Invulnerable { get; set; }</strong>
</td><td>
Set or query unit invulnerablility.
<br />
<b>Requires Trait:</b> ScriptInvulnerable
</td></tr>
<tr><td width="50%" align="right"><strong>bool IsDead { get; }</strong>
</td><td>
Specifies whether the actor is alive or dead.
<br />
<b>Requires Trait:</b> Health
</td></tr>
<tr><td width="50%" align="right"><strong>bool IsIdle { get; }</strong>
</td><td>
Specifies whether the actor is idle (not performing any activities).
</td></tr>
<tr><td width="50%" align="right"><strong>bool IsInWorld { get; set; }</strong>
</td><td>
Specifies whether the actor is in the world.
</td></tr>
<tr><td width="50%" align="right"><strong>CPos Location { get; }</strong>
</td><td>
The actor position in cell coordinates.
</td></tr>
<tr><td width="50%" align="right"><strong>int MaxHealth { get; }</strong>
</td><td>
Maximum health of the actor.
<br />
<b>Requires Trait:</b> Health
</td></tr>
<tr><td width="50%" align="right"><strong>Player Owner { get; }</strong>
</td><td>
The player that owns the actor.
</td></tr>
<tr><td width="50%" align="right"><strong>string Stance { get; set; }</strong>
</td><td>
Current actor stance. Returns nil if this actor doesn't support stances.
</td></tr>
<tr><td width="50%" align="right"><strong>void Stop()</strong>
</td><td>
Attempt to cancel any active activities.
</td></tr>
<tr><td width="50%" align="right"><strong>void Teleport(CPos cell)</strong>
<br /><em>Queued Activity</em>
</td><td>
Instantly moves the actor to the specified cell.
</td></tr>
<tr><td width="50%" align="right"><strong>void Wait(int ticks)</strong>
<br /><em>Queued Activity</em>
</td><td>
Wait for a specified number of game ticks (25 ticks = 1 second).
</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Movement</th></tr>
<tr><td width="50%" align="right"><strong>void Move(CPos cell, int closeEnough = 0)</strong>
<br /><em>Queued Activity</em>
</td><td>
Moves within the cell grid. closeEnough defines an optional range (in cells) that will be considered close enough to complete the activity.
<br />
<b>Requires Trait:</b> Mobile
</td></tr>
<tr><td width="50%" align="right"><strong>void ScriptedMove(CPos cell)</strong>
<br /><em>Queued Activity</em>
</td><td>
Moves within the cell grid, ignoring lane biases.
<br />
<b>Requires Trait:</b> Mobile
</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Production</th></tr>
<tr><td width="50%" align="right"><strong>void Produce(string actorType)</strong>
<br /><em>Queued Activity</em>
</td><td>
Build a unit, ignoring the production queue. The activity will wait if the exit is blocked
<br />
<b>Requires Trait:</b> Production
</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Support Powers</th></tr>
<tr><td width="50%" align="right"><strong>void Chronoshift(LuaTable unitLocationPairs, int duration = 0, bool killCargo = False)</strong>
</td><td>
Chronoshift a group of actors. A duration of 0 will teleport the actors permanently.
<br />
<b>Requires Trait:</b> ChronoshiftPower
</td></tr>
</table>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Transports</th></tr>
<tr><td width="50%" align="right"><strong>bool HasPassengers { get; }</strong>
</td><td>
Specifies whether transport has any passengers.
<br />
<b>Requires Trait:</b> Cargo
</td></tr>
<tr><td width="50%" align="right"><strong>void LoadPassenger(Actor a)</strong>
</td><td>
Teleport an existing actor inside this transport.
<br />
<b>Requires Trait:</b> Cargo
</td></tr>
<tr><td width="50%" align="right"><strong>void Paradrop(CPos cell)</strong>
<br /><em>Queued Activity</em>
</td><td>
Command transport to paradrop passengers near the target cell.
<br />
<b>Requires Traits:</b> Cargo, ParaDrop
</td></tr>
<tr><td width="50%" align="right"><strong>void UnloadPassengers()</strong>
<br /><em>Queued Activity</em>
</td><td>
Command transport to unload passengers.
<br />
<b>Requires Trait:</b> Cargo
</td></tr>
</table>
<h3>Player Properties / Commands</h3>
<table align="center" width="1024"><tr><th colspan="2" width="1024">Resources</th></tr>
<tr><td width="50%" align="right"><strong>int Cash { get; set; }</strong>
</td><td>
The amount of cash held by the player.
<br />
<b>Requires Trait:</b> PlayerResources
</td></tr>
<tr><td width="50%" align="right"><strong>int ResourceCapacity { get; }</strong>
</td><td>
The maximum resource storage of the player.
<br />
<b>Requires Trait:</b> PlayerResources
</td></tr>
<tr><td width="50%" align="right"><strong>int Resources { get; set; }</strong>
</td><td>
The amount of harvestable resources held by the player.
<br />
<b>Requires Trait:</b> PlayerResources
</td></tr>
</table>
